@@ -21,7 +21,7 @@ from squad.core.tasks import get_suite
 logger = logging.getLogger()
 
 
-@celery.task
+@celery.task(queue='ci_fetch')
 def update_build_status(results_list, testrun_id):
     testrun = TestRun.objects.get(pk=testrun_id)
     ProjectStatus.create_or_update(testrun.build)
@@ -244,7 +244,7 @@ class Tradefed(BasePlugin):
                     storage=ET.tostring(test_case).decode('utf-8')
                 )
                 logger.debug("Created plugin scratch with ID: %s" % plugin_scratch.pk)
-                task = create_testcase_tests.s(plugin_scratch.pk, module_name, testrun.pk, suite.pk)
+                task = create_testcase_tests.s(plugin_scratch.pk, atomic_test_suite_name, testrun.pk, suite.pk)
                 task_list.append(task)
 
         celery_chord(task_list)(update_build_status.s(testrun.pk))
@@ -449,7 +449,7 @@ class Tradefed(BasePlugin):
         data = extracted_file.contents.read()
         attachment = testrun.attachments.create(
             filename = name,
-            data = data,
+            old_data = data,
             length = extracted_file.length,
             mimetype = mimetype
         )
@@ -481,8 +481,11 @@ class Tradefed(BasePlugin):
                             try:
                                 results = self._get_from_artifactorial(testjob, test_definition['name'])
                             except xmlrpc.client.ProtocolError as err:
-                                logger.error(err.errcode)
-                                logger.error(err.errmsg)
+                                error_cleaned = 'Failed to process CTS/VTS tests: %s - %s' % (err.errcode, testjob.backend.get_implementation().url_remove_token(str(errmsg)))
+                                logger.warning(error_cleaned)
+
+                                testjob.failure += error_cleaned 
+                                testjob.save()
 
                             logger.debug("Processing results")
                             if results is not None:
